@@ -24,6 +24,9 @@ def external_id_from_subiss(sub=None, iss=None, sub_iss=None):
             raise ValueError('aaaaaaaaa')
         sub_iss = sub+"@"+iss
 
+    if isinstance(sub_iss, list):
+        sub_iss = sub_iss[0]
+
     # Values for testing:
     if sub_iss == 'test-offline':
         print('hdf_marcus')
@@ -39,11 +42,14 @@ def external_id_from_subiss(sub=None, iss=None, sub_iss=None):
         stderr.write("using test id: %s\n" % sub_iss)
 
     # Construct urlencoded sub@iss
-    (sub,iss)  = sub_iss.split('@')
-    external_id = ul.quote_plus(sub) + \
-                '@' + \
-                ul.quote_plus(iss)
-    return external_id
+    try:
+        (sub,iss)  = sub_iss.split('@')
+        external_id = ul.quote_plus(sub) + \
+                    '@' + \
+                    ul.quote_plus(iss)
+        return external_id
+    except ValueError:
+        return None
 def get_userinfo_from_external_id(external_id):
     '''get all userinfo from external_id. Returns the json response of RegApp or raises an Error'''
     # Call regapp
@@ -87,6 +93,8 @@ def get_sshkey_from_external_id (external_id):
     except json.JSONDecodeError:
         logger.error("Cannot find 'ssh_key' in 'genericStore' response of regApp")
         raise
+    except KeyError:
+        return ""
     return sshkeys.rstrip('\n')
 def safe_resp_conversion(resp):
     '''Safely convert a response to json'''
@@ -106,12 +114,14 @@ def get_external_id_from_username(parameter):
     ATTR_USERNAME = 'urn:oid:0.9.2342.19200300.100.1.1'
 
     # find out whether parameter contains a bwidm org id:
-    if len(parameter.split('_')) != 2:
+    if len(parameter.split('_')) < 2:
         logger.warning(F"The provided parameter is not a prefixed username: '{parameter}'")
         username             = parameter
         bwidmorgid_specified = False
     else:
-        (bwidm_org_id, username) = parameter.split('_')
+        parts = parameter.split('_')
+        bwidm_org_id = parts[0]
+        username  = "_".join(parts[1:])
         bwidmorgid_specified     = True
 
     if not bwidmorgid_specified:
@@ -137,3 +147,43 @@ def get_external_id_from_username(parameter):
             return(resp_json['externalId'])
 
     return None # to keep pylint happy
+def get_user_registrations_from_external_id(external_id):
+    '''get all user registrations from external_id. Returns the json response of RegApp or raises an Error'''
+    # Call regapp
+    BWIDM = BwIdmConnection(CONFIG)
+    resp = BWIDM.get ('external-reg', 'find', 'externalId', external_id)
+    resp_json = safe_resp_conversion(resp)
+    return resp_json
+def deregister_external_id_from_service(external_id, service_name):
+    '''deregister user from given service'''
+    # Call regapp
+    BWIDM = BwIdmConnection(CONFIG)
+    resp = BWIDM.get ('external-reg', 'deregister', 'externalId', external_id, 'ssn', service_name)
+    resp_json = safe_resp_conversion(resp)
+    return resp_json
+def deactivate_user(external_id):
+    '''deregister user from given service'''
+    # Call regapp
+    BWIDM = BwIdmConnection(CONFIG)
+    resp = BWIDM.get ('external-user', 'deactivate', 'externalId', external_id)
+    return resp
+def activate_user(external_id):
+    '''deregister user from given service'''
+    # Call regapp
+    BWIDM = BwIdmConnection(CONFIG)
+    resp = BWIDM.get ('external-user', 'activate', 'externalId', external_id)
+    return resp
+def register_external_id_from_service(external_id, service_name):
+    '''register user from given service'''
+    # Call regapp
+    BWIDM = BwIdmConnection(CONFIG)
+    resp = BWIDM.get ('external-reg', 'register', 'externalId', external_id, 'ssn', service_name)
+    resp_json = safe_resp_conversion(resp)
+    return resp_json
+def get_list_of_all_users():
+    '''register user from given service'''
+    # Call regapp
+    BWIDM = BwIdmConnection(CONFIG)
+    resp = BWIDM.get ('external-user', 'find', 'all')
+    resp_json = safe_resp_conversion(resp)
+    return resp_json
