@@ -21,8 +21,7 @@ CONFIG.optionxform = lambda option: option
 def load_config():
     """Reload configuration from disk.
 
-    Config locations, by priority (all values are merged. The last one
-        overwrites earlier ones)
+    Config locations, by priority (first one wins)
     """
     files = []
     try:
@@ -43,11 +42,14 @@ def load_config():
 
     read_a_config = False
     for f in files:
-        if f.exists():
-            logger.info("Using this config file: {}".format(f))
-            CONFIG.read(f)
-            read_a_config = True
-            break
+        try:
+            if f.exists():
+                logger.info("Using this config file: {}".format(f))
+                CONFIG.read(f)
+                read_a_config = True
+                break
+        except PermissionError:
+            pass
     if not read_a_config:
         logger.error(F"Could not read any config file from {files}")
         s_exit(4)
